@@ -1,13 +1,26 @@
 from __future__ import annotations
 
 import asyncio
+from dataclasses import dataclass
 
-from .api import Session
-from .config import ApiInfo, Config
+from yarl import URL
+
+from .session import Session
+
+
+@dataclass
+class ApiInfo:
+    host: str = "localhost"
+    port: int = 5140
+    token: str | None = None
+
+    @property
+    def api_base(self):
+        return URL(f"http://{self.host}:{self.port}") / "v1"
 
 
 class Account:
-    def __init__(self, platform: str, self_id: str, config: Config):
+    def __init__(self, platform: str, self_id: str, config: ApiInfo):
         self.platform = platform
         self.self_id = self_id
         self.config = config
